@@ -1,5 +1,7 @@
 APP_NAME_TO_USECASE = {
     "people_counting": "people_counting",
+    "intrusion_detection": "intrusion_detection",
+    "proximity_detection": "proximity_detection",
     "mask_detection": "mask_detection",
     "pipeline_detection": "pipeline_detection",
     "vehicle_monitoring": "vehicle_monitoring",
@@ -45,13 +47,16 @@ APP_NAME_TO_USECASE = {
     "waterbody_segmentation": "waterbody_segmentation",
     "litter_detection" : "litter_detection",
     "leak_detection": "leak_detection",
-    "fire_smoke_detection": "fire_smoke_detection",
-    "human_activity": "human_activity",
+    "Fire Safety Monitoring": "fire_smoke_detection",
+    "human_activity_recognition": "human_activity_recognition",
+    "abandoned_object_detection" : "abandoned_object_detection",
     "gas_leak_detection": "gas_leak_detection",
 }
 
 APP_NAME_TO_CATEGORY = {
     "people_counting": "general",
+    "intrusion_detection": "security",
+    "proximity_detection": "security",
     "mask_detection": "mask_detection",
     "pipeline_detection": "pipeline_detection",
     "vehicle_monitoring": "traffic",
@@ -97,8 +102,9 @@ APP_NAME_TO_CATEGORY = {
     "waterbody_segmentation": "agriculture",
     "litter_detection" : "litter_detection",
     "leak_detection": "oil_gas",
-    "fire_smoke_detection": "hazard",
-    "human_activity": "general",
+    "Fire Safety Monitoring": "hazard",
+    "human_activity_recognition": "general",
+    "abandoned_object_detection" : "security",
     "gas_leak_detection": "oil_gas",
 }
 
